import 'dart:collection';
import 'dart:io';

import 'package:d_dio/src/type/type.dart';
import 'package:flutter/foundation.dart';

class BaseReq {
  final bool needToken; //是否需要token
  final CacheReader cacheReader;

  late String language;
  late String channel;
  late String version;
  late String time;
  late String deviceId;
  late String ip;
  String? token;

  int get platform => kIsWeb ? 1 : 3;

  String get system => kIsWeb
      ? 'h5'
      : Platform.isIOS
          ? 'ios'
          : 'android';

  BaseReq({this.needToken = false, required this.cacheReader}) {
    time = DateTime.now().millisecondsSinceEpoch.toString();

    language = cacheReader('language', defaultValue: 'zh-CN')!;

    channel = cacheReader('channel', defaultValue: 'unknown')!;

    version = cacheReader('version', defaultValue: '0.0.0')!;

    deviceId = cacheReader('device_id', defaultValue: 'unknown')!;

    ip = cacheReader('ip', defaultValue: '0.0.0.0')!;

    if (needToken) token = cacheReader('token', defaultValue: '')!;
  }

  Map<String, dynamic> toJson() {
    final data = SplayTreeMap<String, dynamic>();
    data['language'] = language;
    data['platform'] = platform;
    data['system'] = system;
    data['version'] = version;
    data['time'] = time;
    data['device_id'] = deviceId;
    data['ip'] = ip;
    if (needToken) data['token'] = token;

    return data;
  }
}
